package com.ruoyi.system.mapper;

import java.time.LocalDate;
import java.util.Date;
import java.util.List;
import com.ruoyi.system.domain.InspectInfor;
import org.apache.ibatis.annotations.Param;

/**
 * 送检信息Mapper接口
 * 
 * @author boman
 * @date 2021-12-27
 */
public interface InspectInforMapper 
{
    /**
     * 查询送检信息
     * 
     * @param inspectId 送检信息主键
     * @return 送检信息
     */
    public InspectInfor selectInspectInforByInspectId(Long inspectId);

    /**
     * 查询送检信息列表
     * 
     * @param inspectInfor 送检信息
     * @return 送检信息集合
     */
    public List<InspectInfor> selectInspectInforList(InspectInfor inspectInfor);

    /**
     * 新增送检信息
     * 
     * @param inspectInfor 送检信息
     * @return 结果
     */
    public int insertInspectInfor(InspectInfor inspectInfor);

    /**
     * 修改送检信息
     * 
     * @param inspectInfor 送检信息
     * @return 结果
     */
    public int updateInspectInfor(InspectInfor inspectInfor);

    /**
     * 删除送检信息
     * 
     * @param inspectId 送检信息主键
     * @return 结果
     */
    public int deleteInspectInforByInspectId(Long inspectId);

    /**
     * 批量删除送检信息
     * 
     * @param inspectIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInspectInforByInspectIds(Long[] inspectIds);

    /**
     * 校验样品名称的唯一性
     * @param sampleName
     * @return
     */
    InspectInfor checkSampleNameUnique(@Param("sampleName") String sampleName);


    /**
     * 查询送检次数
     * @param startTime
     * @param endTime
     * @return
     */
   int selectInspectInforCount(@Param("today") LocalDate today,@Param("startTime") LocalDate startTime,@Param("endTime") LocalDate endTime);
}
